@@ -43,9 +43,9 @@ class NormalizingFlow(TransformedDistribution):
         base: A base distribution :math:`p(Z)`.
 
     Example:
-        >>> d = NormalizingFlow([ExpTransform().inv], Normal(0, 1))
+        >>> d = NormalizingFlow([ExpTransform()], Gamma(2.0, 1.0))
         >>> d.sample()
-        tensor(0.1316)
+        tensor(1.1316)
     """
 
     def __init__(
@@ -80,7 +80,7 @@ class Joint(Distribution):
         marginals: A list of distributions :math:`p(Z_i)`.
 
     Example:
-        >>> d = Joint(Uniform(0, 1), Normal(0, 1))
+        >>> d = Joint(Uniform(0.0, 1.0), Normal(0.0, 1.0))
         >>> d.event_shape
         torch.Size([2])
         >>> d.sample()
@@ -98,10 +98,7 @@ class Joint(Distribution):
 
     @property
     def event_shape(self) -> Size:
-        return Size([sum(
-            m.event_shape.numel()
-            for m in self.marginals
-        )])
+        return Size([sum(m.event_shape.numel() for m in self.marginals)])
 
     def expand(self, batch_shape: Size, new: Distribution = None) -> Distribution:
         new = self._get_checked_instance(Joint, new)
@@ -132,7 +129,7 @@ class Joint(Distribution):
 
         for m in self.marginals:
             z = m.rsample(shape)
-            z = z.reshape(shape + (-1,))
+            z = z.reshape(shape + m.batch_shape + (-1,))
             x.append(z)
 
         return torch.cat(x, dim=-1)
@@ -143,7 +140,7 @@ class Joint(Distribution):
         with torch.no_grad():
             for m in self.marginals:
                 z = m.sample(shape)
-                z = z.reshape(shape + (-1,))
+                z = z.reshape(shape + m.batch_shape + (-1,))
                 x.append(z)
 
         return torch.cat(x, dim=-1)
@@ -159,6 +156,11 @@ class GeneralizedNormal(Distribution):
 
     Arguments:
         beta: The shape parameter :math:`\beta`.
+
+    Example:
+        >>> d = GeneralizedNormal(2.0)
+        >>> d.sample()
+        tensor(0.7480)
     """
 
     arg_constraints = {'beta': constraints.positive}
@@ -181,12 +183,12 @@ class GeneralizedNormal(Distribution):
         return (
             torch.log(self.beta / 2)
             - torch.lgamma(1 / self.beta)
-            - abs(x)**self.beta
+            - abs(x) ** self.beta
         )
 
     def rsample(self, shape: Size = ()) -> Tensor:
         beta = self.beta.expand(shape + self.beta.shape)
-        x = torch._standard_gamma(1 / beta)**(1 / beta)
+        x = torch._standard_gamma(1 / beta) ** (1 / beta)
         x = x * torch.sign(2 * torch.rand_like(x) - 1)
         return x
 
@@ -271,13 +273,13 @@ class TransformedUniform(NormalizingFlow):
         upper: An upper bound :math:`u` (exclusive).
 
     Example:
-        >>> d = TransformedUniform(ExpTransform(), -1, 1)
+        >>> d = TransformedUniform(ExpTransform(), -1.0, 1.0)
         >>> d.sample()
         tensor(0.5594)
     """
 
     def __init__(self, f: Transform, lower: Tensor, upper: Tensor):
-        super().__init__([f], Uniform(f(lower), f(upper)))
+        super().__init__([f], Uniform(*map(f, map(torch.as_tensor, (lower, upper)))))
 
     def expand(self, batch_shape: Size, new: Distribution = None) -> Distribution:
         new = self._get_checked_instance(TransformedUniform, new)
@@ -300,7 +302,7 @@ class Truncated(Distribution):
         upper: An upper bound :math:`u` (exclusive).
 
     Example:
-        >>> d = Truncated(Normal(0, 1), 1, 2)
+        >>> d = Truncated(Normal(0.0, 1.0), 1.0, 2.0)
         >>> d.sample()
         tensor(1.2573)
     """
@@ -313,9 +315,9 @@ class Truncated(Distribution):
         lower: Tensor = float('-inf'),
         upper: Tensor = float('+inf'),
     ):
-        super().__init__(batch_shape=batch_shape)
+        super().__init__(batch_shape=base.batch_shape)
 
-        assert len(base.event_shape) < 1, "base must be univariate"
+        assert len(base.event_shape) < 1, "'base' has to be univariate"
 
         self.base = base
         self.uniform = Uniform(base.cdf(lower), base.cdf(upper))
@@ -358,7 +360,7 @@ class Sort(Distribution):
         descending: Whether the elements are sorted in descending order or not.
 
     Example:
-        >>> d = Sort(Normal(0, 1), 3)
+        >>> d = Sort(Normal(0.0, 1.0), 3)
         >>> d.event_shape
         torch.Size([3])
         >>> d.sample()
@@ -373,7 +375,7 @@ class Sort(Distribution):
     ):
         super().__init__(batch_shape=base.batch_shape)
 
-        assert len(base.event_shape) < 1, "base must be univariate"
+        assert len(base.event_shape) < 1, "'base' has to be univariate"
 
         self.base = base
         self.n = n
@@ -399,25 +401,20 @@ class Sort(Distribution):
         return new
 
     def log_prob(self, x: Tensor) -> Tensor:
+        x = torch.movedim(x, -1, 0)
+
         if self.descending:
-            ordered = x[..., :-1] >= x[..., 1:]
+            ordered = x[:-1] >= x[1:]
         else:
-            ordered = x[..., :-1] <= x[..., 1:]
+            ordered = x[:-1] <= x[1:]
 
-        ordered = ordered.all(dim=-1)
+        ordered = ordered.all(dim=0)
 
-        return (
-            ordered.log()
-            + self.log_fact
-            + self.base.log_prob(x).sum(dim=-1)
-        )
+        return ordered.log() + self.log_fact + self.base.log_prob(x).sum(dim=0)
 
     def sample(self, shape: Size = ()) -> Tensor:
-        x = torch.stack([
-            self.base.sample(shape)
-            for _ in range(self.n)
-        ], dim=-1)
-        x, _ = torch.sort(x, dim=-1, descending=self.descending)
+        x = torch.movedim(self.base.sample((self.n,) + shape), 0, -1)
+        x = torch.sort(x, dim=-1, descending=self.descending).values
 
         return x
 
@@ -440,7 +437,7 @@ class TopK(Sort):
         kwargs: Keyword arguments passed to :class:`Sort`.
 
     Example:
-        >>> d = TopK(Normal(0, 1), 2, 3)
+        >>> d = TopK(Normal(0.0, 1.0), 2, 3)
         >>> d.event_shape
         torch.Size([2])
         >>> d.sample()
@@ -456,7 +453,7 @@ class TopK(Sort):
     ):
         super().__init__(base, n, **kwargs)
 
-        assert 1 <= k < n, "k should be in [1, n)"
+        assert 1 <= k < n, "k has to be in [1, n)"
 
         self.k = k
         self.log_fact = self.log_fact - math.log(math.factorial(n - k))
@@ -482,7 +479,7 @@ class TopK(Sort):
         return (self.n - self.k) * cdf.log() + super().log_prob(x)
 
     def sample(self, shape: Size = ()) -> Tensor:
-        return super().sample(shape)[..., :self.k]
+        return super().sample(shape)[..., : self.k]
 
 
 class Minimum(TopK):
@@ -496,7 +493,7 @@ class Minimum(TopK):
         n: The number of draws :math:`n`.
 
     Example:
-        >>> d = Minimum(Normal(0, 1), 3)
+        >>> d = Minimum(Normal(0.0, 1.0), 3)
         >>> d.event_shape
         torch.Size([])
         >>> d.sample()
@@ -537,7 +534,7 @@ class Maximum(Minimum):
         n: The number of draws :math:`n`.
 
     Example:
-        >>> d = Maximum(Normal(0, 1), 3)
+        >>> d = Maximum(Normal(0.0, 1.0), 3)
         >>> d.event_shape
         torch.Size([])
         >>> d.sample()
